diff --git a/src/main/java/net/minecraft/core/item/ItemJar.java b/src/main/java/net/minecraft/core/item/ItemJar.java
index bb0762fa8..2bafe100a 100644
--- a/src/main/java/net/minecraft/core/item/ItemJar.java
+++ b/src/main/java/net/minecraft/core/item/ItemJar.java
@@ -1,13 +1,18 @@
 package net.minecraft.core.item;
 
 import net.minecraft.core.block.Block;
+import net.minecraft.core.block.BlockFluid;
 import net.minecraft.core.entity.Entity;
 import net.minecraft.core.entity.animal.EntityFireflyCluster;
 import net.minecraft.core.entity.player.EntityPlayer;
+import net.minecraft.core.enums.EnumBlockSoundEffectType;
+import net.minecraft.core.util.helper.Side;
 import net.minecraft.core.world.World;
 
 import java.util.List;
 
+import static net.minecraft.core.world.LevelListener.EVENT_BLOCK_BREAK;
+
 public class ItemJar extends ItemPlaceable{
 
     protected ItemJar(String name, int id) {
@@ -15,9 +20,25 @@ public class ItemJar extends ItemPlaceable{
         setMaxStackSize(64);
     }
 
+    @Override
+    public boolean onUseItemOnBlock(ItemStack stack, EntityPlayer player, World world, int blockX, int blockY, int blockZ, Side side, double xPlaced, double yPlaced) {
+        if (player.isSneaking()) {
+            return super.onUseItemOnBlock(stack, player, world, blockX, blockY, blockZ, side, xPlaced, yPlaced);
+        }
+        int count = stack.stackSize;
+        ItemStack used = onUseItem(stack, world, player);
+        if (used != null && used.stackSize != count){
+            return true;
+        }
+        return super.onUseItemOnBlock(stack, player, world, blockX, blockY, blockZ, side, xPlaced, yPlaced);
+    }
+
     @Override
     public ItemStack onUseItem(ItemStack itemstack, World world, EntityPlayer entityplayer)
     {
+        if (entityplayer.isSneaking()) {
+            return itemstack;
+        }
         List<Entity> list = world.getEntitiesWithinAABBExcludingEntity(entityplayer,entityplayer.bb.expand(2, 2, 2));
         
         for(Entity entity : list){
